@@ -2,8 +2,8 @@ package t::Utils;
 use strict;
 use warnings;
 use utf8;
+use lib './t/lib';
 use Test::More;
-use lib './t';
 
 BEGIN {
   eval "use DBD::SQLite";
@@ -16,5 +16,11 @@ sub import {
     utf8->import;
 }
 
+sub setup_dbh {
+    shift;
+    my $file = shift || ':memory:';
+    DBI->connect('dbi:SQLite:'.$file,'','',{RaiseError => 1, PrintError => 0, AutoCommit => 1});
+}
+
 1;
 
